#
# spec file for package python-tifffile
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-tifffile%{psuffix}
Version:        2024.9.20
Release:        1.1
Summary:        Read and write TIFF files
License:        BSD-2-Clause
URL:            https://github.com/cgohlke/tifffile/
Source:         https://github.com/cgohlke/tifffile/archive/v%{version}.tar.gz#/tifffile-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module numpy >= 1.21}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-fsspec
Recommends:     python-imagecodecs >= 2023.3.16
Recommends:     python-lxml
Recommends:     python-matplotlib >= 3.3
Recommends:     python-zarr
# SECTION test
%if %{with test}
BuildRequires:  %{python_module cmapfile}
BuildRequires:  %{python_module czifile}
BuildRequires:  %{python_module dask}
BuildRequires:  %{python_module defusedxml}
BuildRequires:  %{python_module fsspec}
BuildRequires:  %{python_module imagecodecs >= 2023.3.16}
BuildRequires:  %{python_module lfdfiles}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module ndtiff}
BuildRequires:  %{python_module oiffile}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module roifile}
BuildRequires:  %{python_module xarray if %python-base >= 3.10}
BuildRequires:  %{python_module zarr}
%endif
# /SECTION
BuildArch:      noarch
%python_subpackages

%description
Read and write TIFF files. Read image and metadata from many
bio-scientific formats such as plain TIFF, BigTIFF, OME-TIFF, STK, LSM,
SGI, NIH, ImageJ, MicroManager, MD GEL, and FluoView files. Write numpy
arrays to TIFF, BigTIFF, and ImageJ hyperstack compatible files.

%prep
%setup -q -n tifffile-%{version}
# Fix warning wrong-file-end-of-line-encoding
sed -i 's/\r//' README.rst
sed -i '1{/env python/d}' tifffile/{lsm2bin,tiff2fsspec,tiffcomment}.py

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/tifffile
%python_clone -a %{buildroot}%{_bindir}/lsm2bin
%python_clone -a %{buildroot}%{_bindir}/tiffcomment
%python_clone -a %{buildroot}%{_bindir}/tiff2fsspec

%python_expand %fdupes %{buildroot}%{$python_sitelib}
%prepare_alternative tifffile
%prepare_alternative lsm2bin
%prepare_alternative tiffcomment
%endif

%post
%python_install_alternative tifffile
%python_install_alternative lsm2bin
%python_install_alternative tiffcomment
%python_install_alternative tiff2fsspec

%postun
%python_uninstall_alternative tifffile
%python_uninstall_alternative lsm2bin
%python_uninstall_alternative tiffcomment
%python_uninstall_alternative tiff2fsspec

%check
%if %{with test}
# Crashes Out-Of-Memory
donttest="test_write_5GB_bigtiff or test_write_imagej_raw"
# no lerc support in imagecodecs
donttest="$donttest or test_write_compression_lerc"
# flaky write errors
donttest="$donttest or test_write_extrasamples_planar"
donttest="$donttest or test_write_extrasamples_contig_rgb"
donttest="$donttest or test_write_compression_args"
donttest="$donttest or test_issue_invalid_predictor"
%pytest -n auto -k "not ($donttest)"
%endif

%if !%{with test}
%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/tifffile
%python_alternative %{_bindir}/lsm2bin
%python_alternative %{_bindir}/tiffcomment
%python_alternative %{_bindir}/tiff2fsspec
%{python_sitelib}/tifffile-%{version}.dist-info/
%{python_sitelib}/tifffile
%endif

%changelog
* Sat Nov  9 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.9.20:
  * Pass 5107 tests.
  * Fix writing colormap to ImageJ files (breaking).
  * Improve typing.
  * Remove support for Python 3.9.
  * Support writing OME Dataset and some StructuredAnnotations
    elements.
  * Fix LSM scan types and dimension orders (#269, breaking).
  * Use IO[bytes] instead of BinaryIO for typing (#268).
  * Do not remove trailing length-1 dimension writing non-shaped
    file (breaking).
  * Fix writing OME-TIFF with certain modulo axes orders.
  * Make imshow NaN aware.
  * Relax bitspersample check for JPEG, JPEG2K, and JPEGXL
    compression (#265).
  * Fix reading contiguous multi-page series via Zarr store
    (#67).
  * Fix integer overflow in product function caused by numpy
    types.
  * Allow tag reader functions to fail.
  * Enable memmap to create empty files with non-native byte
    order.
  * Deprecate Python 3.9, support Python 3.13.
* Wed Jul 17 2024 Ben Greiner <code@bnavigator.de>
- Revert. Numpy 2 is supported since 2024.2.12
* Wed Jul 17 2024 Steve Kowalik <steven.kowalik@suse.com>
- Restrict numpy to < 2.
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.6.18:
  * Ensure TiffPage.nodata is castable to dtype (breaking, #260).
  * Derive TiffPages, TiffPageSeries, FileSequence, StoredShape
    from Sequence.
  * Truncate circular IFD chain, do not raise TiffFileError
    (breaking).
  * Deprecate access to TiffPages.pages and FileSequence.files.
  * Enable DeprecationWarning for enums in TIFF namespace.
  * Remove some deprecated code (breaking).
  * Add iccprofile property to TiffPage and parameter to
    TiffWriter.write.
  * Do not detect VSI as SIS format.
  * Limit length of logged exception messages.
  * Fix docstring examples not correctly rendered on GitHub
    (#254, #255).
  * Support reading JPEGXL compression in DNG 1.7.
  * Read invalid TIFF created by IDEAS software.
  * Fix reading incompletely written LSM.
  * Fix reading Philips DP with extra rows of tiles (#253,
    breaking).
  * Fix compatibility issue with numpy 2 (#252).
  * Fix write_fsspec when last row of tiles is missing in Philips
    slide (#249).
  * Add option not to quote file names in write_fsspec.
  * Allow compress bilevel images with deflate, LZMA, and Zstd.
* Sun Mar  3 2024 Ben Greiner <code@bnavigator.de>
- Update to 2024.2.12
  * Deprecate dtype, add chunkdtype parameter in
    FileSequence.asarray.
  * Add imreadargs parameters passed to FileSequence.imread.
- Release 2024.1.30
  * Fix compatibility issue with numpy 2 (#238).
  * Enable DeprecationWarning for tuple compression argument.
  * Parse sequence of numbers in xml2dict.
- Don't test xarray on python39: no longer available
* Wed Dec 27 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.12.9:
  * Read 32-bit Indica Labs TIFF as float32.
  * Fix UnboundLocalError reading big LSM files without time
    axis.
  * Use os.sched_getaffinity, if available, to get the number of
    CPUs (#231).
  * Limit the number of default worker threads to 32.
  * Lazily convert dask array to ndarray when writing.
  * Allow to specify buffersize for reading and writing.
  * Fix IndexError reading some corrupted files with
    ZarrTiffStore (#227).
  * Raise exception when writing non-volume data with volumetric
    tiles (#225).
  * Improve multi-threaded writing of compressed multi-page
    files.
  * Fix fsspec reference for big-endian files with predictors.
* Tue Sep 12 2023 Markéta Machová <mmachova@suse.com>
- Update to 2023.8.30
  * Support decompressing EER frames.
  * Facilitate filtering logged warnings (#216).
  * Read more tags from UIC1Tag (#217).
  * Fix premature closing of files in main (#218).
  * Don't force matplotlib backend to tkagg in main (#219).
  * Add py.typed marker.
  * Drop support for imagecodecs < 2023.3.16.
  * Verify shaped metadata is compatible with page shape.
  * Support out parameter when returning selection from imread (#222).
  * Support exclusive file creation mode (#221, #223).
* Thu Aug  3 2023 Markéta Machová <mmachova@suse.com>
- Update to 2023.7.18
  * Add option to return selection from imread
  * Fix reading OME series with missing trailing frames
  * Drop support for Python 3.8 and numpy < 1.21 (NEP29).
  * Increase default strip size to 256 KB when writing with compression.
  * Fix ZarrTiffStore with non-default chunkmode.
  * Pass 4993 tests.
  * Limit threading via TIFFFILE_NUM_THREADS environment variable
  * Remove maxworkers parameter from tiff2fsspec (breaking).
* Wed May 31 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.4.12:
  * Pass 4988 tests.
  * Do not write duplicate ImageDescription tags from extratags
    (breaking).
  * Support multifocal SVS files (#193).
  * Log warning when filtering out extratags.
  * Fix writing OME-TIFF with image description in extratags.
  * Ignore invalid predictor tag value if prediction is not used.
  * Raise KeyError if ZarrStore is missing requested chunk.
  * 2023.3.21
  * Fix reading MMstack with missing data (#187).
* Wed May 24 2023 Jan Engelhardt <jengelh@inai.de>
- Drop TM/R marks according to packaging guidelines.
* Sat Apr  1 2023 Ben Greiner <code@bnavigator.de>
- Update to 2023.3.15
  * Pass 4980 tests.
  * Fix corruption using tile generators with
    prediction/compression (#185).
  * Add parser for Micro-Manager MMStack series (breaking).
  * Return micromanager_metadata IndexMap as numpy array
    (breaking).
  * Revert optimizations for Micro-Manager OME series.
  * Do not use numcodecs zstd in write_fsspec (kerchunk issue 317).
  * More type annotations.
- Release 2023.2.28
  * Fix reading some Micro-Manager metadata from corrupted files.
  * Speed up reading Micro-Manager indexmap for creation of OME
    series.
- Release 2023.2.27
  * Use Micro-Manager indexmap offsets to create virtual
    TiffFrames.
  * Fixes for future imagecodecs.
- Release 2023.2.3
  * Fix overflow in calculation of databytecounts for large NDPI
    files.
- Release 2023.2.2
  * Fix regression reading layered NDPI files.
  * Add option to specify offset in FileHandle.read_array.
- Release 2023.1.23
  * Support reading NDTiffStorage.
  * Support reading PIXTIFF compression.
  * Support LERC with Zstd or Deflate compression.
  * Do not write duplicate and select extratags.
  * Allow to write uncompressed image data beyond 4 GB in classic
    TIFF.
  * Add option to specify chunkshape and dtype in
    FileSequence.asarray.
  * Add option for imread to write to output in
    FileSequence.asarray (#172).
  * Add function to read GDAL structural metadata.
  * Add function to read NDTiff.index files.
  * Fix IndexError accessing TiffFile.mdgel_metadata in non-MDGEL
    files.
  * Fix unclosed file ResourceWarning in TiffWriter.
  * Fix non-bool predictor arguments (#167).
  * Relax detection of OME-XML (#173).
  * Rename some TiffFrame parameters (breaking).
  * Deprecate squeeze_axes (will change signature).
  * Use defusexml in xml2dict.
- Do not test xarry on python38: not supported anymore
* Tue Feb 21 2023 Steve Kowalik <steven.kowalik@suse.com>
- Inject multibuild to fix a bootstrapping issue.
* Sat Jan 21 2023 Ben Greiner <code@bnavigator.de>
- Update to 2022.10.10.
  * Pass 4925 tests.
  * Fix RecursionError in peek_iterator.
  * Fix reading NDTiffv3 summary settings.
  * Fix svs_description_metadata parsing (#149).
  * Fix ImportError if Python was built without zlib or lzma.
  * Fix bool of COMPRESSION and PREDICTOR instances.
  * Deprecate non-sequence extrasamples arguments.
  * Parse SCIFIO metadata as ImageJ.
- Release 2022.8.12
  * Fix writing ImageJ format with hyperstack argument.
  * Fix writing description with metadata disabled.
  * Add option to disable writing shaped metadata in TiffWriter.
- Release 2022.8.8
  * Fix regression using imread out argument (#147).
  * Fix imshow show argument.
  * Support fsspec OpenFile.
- Release 2022.8.3
  * Fix regression writing default resolutionunit (#145).
  * Add strptime function parsing common datetime formats.
- Release 2022.7.31
  * Fix reading corrupted WebP compressed segments missing alpha
    channel (#122).
  * Fix regression reading compressed ImageJ files.
- Release 2022.7.28
  * Rename FileSequence.labels attribute to dims (breaking).
  * Rename tifffile_geodb module to geodb (breaking).
  * Rename TiffFile._astuple method to astuple (breaking).
  * Rename noplots command line argument to maxplots (breaking).
  * Fix reading ImageJ hyperstacks with non-TZC order.
  * Fix colorspace of JPEG segments encoded by Bio-Formats.
  * Fix fei_metadata for HELIOS FIB-SEM (#141, needs test).
  * Add xarray style properties to TiffPage (WIP).
  * Add option to specify OME-XML for TiffFile.
  * Add option to control multiscales in ZarrTiffStore.
  * Support writing to uncompressed ZarrTiffStore.
  * Support writing empty images with tiling.
  * Support overwriting some tag values in NDPI (#137).
  * Support Jetraw compression (experimental).
  * Standardize resolution parameter and property.
  * Deprecate third resolution argument on write (use
    resolutionunit).
  * Deprecate tuple type compression argument on write (use
    compressionargs).
  * Deprecate enums in TIFF namespace (use enums from module).
  * Improve default number of threads to write compressed segments
    (#139).
  * Parse metaseries time values as datetime objects (#143).
  * Increase internal read and write buffers to 256 MB.
  * Convert some warnings to debug messages.
  * Declare all classes final.
  * Add script to generate documentation via Sphinx.
  * Convert docstrings to Google style with Sphinx directives.
- Release 2022.5.4
  * Allow to write NewSubfileType=0 (#132).
  * Support writing iterators of strip or tile bytes.
  * Convert iterables (not iterators) to NumPy arrays when writing.
  * Explicitly specify optional keyword parameters for imread and
    imwrite.
  * Return number of written bytes from FileHandle write functions.
- Release 2022.4.28
  * Add option to specify fsspec version 1 URL template name
    (#131).
  * Ignore invalid dates in UIC tags (#129).
  * Fix zlib_encode and lzma_encode to work with non-contiguous
    arrays (#128).
  * Fix delta_encode to preserve byteorder of ndarrays.
  * Move Imagecodecs fallback functions to private module and add
    tests.
- Release 2022.4.26
  * Fix AttributeError in TiffFile.shaped_metadata (#127).
  * Fix TiffTag.overwrite with pre-packed binary value.
  * Write sparse TIFF if tile iterator contains None.
  * Raise ValueError when writing photometric mode with too few
    samples.
  * Improve test coverage.
- Release 2022.4.22
  * Add type hints for Python 3.10 (WIP).
  * Fix Mypy errors (breaking).
  * Mark many parameters positional-only or keyword-only
    (breaking).
  * Remove deprecated pages parameter from imread (breaking).
  * Remove deprecated compress and ijmetadata write parameters
    (breaking).
  * Remove deprecated fastij and movie parameters from TiffFile
    (breaking).
  * Remove deprecated multifile parameters from TiffFile
    (breaking).
  * Remove deprecated tif parameter from TiffTag.overwrite
    (breaking).
  * Remove deprecated file parameter from FileSequence.asarray
    (breaking).
  * Remove option to pass imread class to FileSequence (breaking).
  * Remove optional parameters from __str__ functions (breaking).
  * Rename TiffPageSeries.offset to dataoffset (breaking)
  * Change TiffPage.pages to None if no SubIFDs are present
    (breaking).
  * Change TiffPage.index to int (breaking).
  * Change TiffPage.is_contiguous, is_imagej, and is_shaped to bool
    (breaking).
  * Add TiffPage imagej_description and shaped_description
    properties.
  * Add TiffFormat abstract base class.
  * Deprecate lazyattr and use functools.cached_property instead
    (breaking).
  * Julian_datetime raises ValueError for dates before year 1
    (breaking).
  * Regressed import time due to typing.
- Release 2022.4.8
  * Add _ARRAY_DIMENSIONS attributes to ZarrTiffStore.
  * Allow C instead of S axis when writing OME-TIFF.
  * Fix writing OME-TIFF with separate samples.
  * Fix reading unsqueezed pyramidal OME-TIFF series.
- Release 2022.3.25
  * Fix another ValueError using ZarrStore with zarr >= 2.11.0
    (tiffslide #25).
  * Add parser for Hamamatsu streak metadata.
  * Improve hexdump.
- Release 2022.3.16
  * Use multi-threading to compress strips and tiles.
  * Raise TiffFileError when reading corrupted strips and tiles
    (#122).
  * Fix ScanImage single channel count (#121).
  * Add parser for AstroTIFF FITS metadata.
- Release 2022.2.9
  * Fix ValueError using multiscale ZarrStore with zarr >= 2.11.0.
  * Raise KeyError if ZarrStore does not contain key.
  * Limit number of warnings for missing files in multifile series.
  * Allow to save colormap to 32-bit ImageJ files (#115).
- Release 2022.2.2
  * Fix TypeError when second ImageDescription tag contains
    non-ASCII (#112).
  * Fix parsing IJMetadata with many IJMetadataByteCounts (#111).
  * Detect MicroManager NDTiffv2 header (not tested).
  * Remove cache from ZarrFileSequenceStore (use
    zarr.LRUStoreCache).
  * Raise limit on maximum number of pages.
  * Use J2K format when encoding JPEG2000 segments.
  * Formally deprecate imsave and TiffWriter.save.
  * Drop support for Python 3.7 and NumPy < 1.19 (NEP29).
- Release 2021.11.2
  * Lazy-load non-essential tag values (breaking).
  * Warn when reading from closed file.
  * Support ImageJ prop metadata type (#103).
  * Support writing indexed ImageJ format.
  * Fix multi-threaded access of multi-page Zarr stores with
    chunkmode 2.
  * Raise error if truncate is used with compression, packints, or
    tile.
  * Read STK metadata without UIC2tag.
  * Improve log and warning messages (WIP).
  * Improve string representation of large tag values.
- Release 2021.10.12
  * Revert renaming of file parameter in FileSequence.asarray
    (breaking).
  * Deprecate file parameter in FileSequence.asarray.
- Release 2021.10.10
  * Disallow letters as indices in FileSequence; use categories
    (breaking).
  * Do not warn of missing files in FileSequence; use files_missing
    property.
  * Support predictors in ZarrTiffStore.write_fsspec.
  * Add option to specify Zarr group name in write_fsspec.
  * Add option to specify categories for FileSequence patterns
    (#76).
  * Add option to specify chunk shape and dtype for
    ZarrFileSequenceStore.
  * Add option to tile ZarrFileSequenceStore and
    FileSequence.asarray.
  * Add option to pass additional zattrs to Zarr stores.
  * Detect Roche BIF files.
- Release 2021.8.30
  * Fix horizontal differencing with non-native byte order.
  * Fix multi-threaded access of memory-mappable, multi-page Zarr
    stores (#67).
- Release 2021.8.8
  * Fix tag offset and valueoffset for NDPI > 4 GB (#96).
- Release 2021.7.30
  * Deprecate first parameter to TiffTag.overwrite (no longer
    required).
  * TiffTag init API change (breaking).
  * Detect Ventana BIF series and warn that tiles are not stitched.
  * Enable reading PreviewImage from RAW formats (#93, #94).
  * Work around numpy.ndarray.tofile is very slow for
    non-contiguous arrays.
  * Fix issues with PackBits compression (requires imagecodecs
    2021.7.30).
- Release 2021.7.2
  * Decode complex integer images found in SAR GeoTIFF.
  * Support reading NDPI with JPEG-XR compression.
  * Deprecate TiffWriter RGB auto-detection, except for RGB24/48
    and RGBA32/64.
- Release 2021.6.14
  * Set stacklevel for deprecation warnings (#89).
  * Fix svs_description_metadata for SVS with double header (#88,
    breaking).
  * Fix reading JPEG compressed CMYK images.
  * Support ALT_JPEG and JPEG_2000_LOSSY compression found in
    Bio-Formats.
  * Log warning if TiffWriter auto-detects RGB mode (specify
    photometric).
- Release 2021.6.6
  * Fix TIFF.COMPESSOR typo (#85).
  * Round resolution numbers that do not fit in 64-bit rationals
    (#81).
  * Add support for JPEG XL compression.
  * Add Numcodecs compatible TIFF codec.
  * Rename ZarrFileStore to ZarrFileSequenceStore (breaking).
  * Add method to export fsspec ReferenceFileSystem from
    ZarrFileStore.
  * Fix fsspec ReferenceFileSystem v1 for multifile series.
  * Fix creating OME-TIFF with micron character in OME-XML.
- Release 2021.4.8
  * Fix reading OJPEG with wrong photometric or samplesperpixel
    tags (#75).
  * Fix fsspec ReferenceFileSystem v1 and JPEG compression.
  * Use TiffTagRegistry for NDPI_TAGS, EXIF_TAGS, GPS_TAGS,
    IOP_TAGS constants.
  * Make TIFF.GEO_KEYS an Enum (breaking).
- Release 2021.3.31
  * Use JPEG restart markers as tile offsets in NDPI.
  * Support version 1 and more codecs in fsspec ReferenceFileSystem
    (untested).
- Release 2021.3.17
  * Fix regression reading multi-file OME-TIFF with missing files
    (#72).
  * Fix fsspec ReferenceFileSystem with non-native byte order
    (#56).
- Release 2021.3.16
  * TIFF is no longer a defended trademark.
  * Add method to export fsspec ReferenceFileSystem from
    ZarrTiffStore (#56).
- Release 2021.3.5
  * Preliminary support for EER format (#68).
  * Do not warn about unknown compression (#68).
- Release 2021.3.4
  * Fix reading multi-file, multi-series OME-TIFF (#67).
  * Detect ScanImage 2021 files (#46).
  * Shape new version ScanImage series according to metadata
    (breaking).
  * Remove Description key from TiffFile.scanimage_metadata dict
    (breaking).
  * Also return ScanImage version from read_scanimage_metadata
    (breaking).
  * Fix docstrings.
- Release 2021.2.26
  * Squeeze axes of LSM series by default (breaking).
  * Add option to preserve single dimensions when reading from
    series (WIP).
  * Do not allow appending to OME-TIFF files.
  * Fix reading STK files without name attribute in metadata.
  * Make TIFF constants multi-thread safe and pickleable (#64).
  * Add detection of NDTiffStorage MajorVersion to
    read_micromanager_metadata.
  * Support ScanImage v4 files in read_scanimage_metadata.
- Release 2021.2.1
  * Fix multi-threaded access of ZarrTiffStores using same TiffFile
    instance.
  * Use fallback zlib and lzma codecs with imagecodecs lite builds.
  * Open Olympus and Panasonic RAW files for parsing, albeit not
    supported.
  * Support X2 and X4 differencing found in DNG.
  * Support reading JPEG_LOSSY compression found in DNG.
* Mon Feb  8 2021 Markéta Machová <mmachova@suse.com>
- Skip python36 because of imagecodecs
* Sun Jan 31 2021 andy great <andythe_great@pm.me>
- Add missing python_alternative.
* Mon Jan 25 2021 andy great <andythe_great@pm.me>
- Update to version 2021.1.14.
  * Try ImageJ series if OME series fails
  * Add option to use pages as chunks in ZarrFileStore (experimental).
  * Fix reading from file objects with no readinto function.
- Updates for version 2021.1.11
  * Fix test errors on PyPy.
  * Fix decoding bitorder with imagecodecs >= 2021.1.11.
- Updates for version 2021.1.8
  * Decode float24 using imagecodecs >= 2021.1.8.
  * Consolidate reading of segments if possible.
* Mon Dec 28 2020 andy great <andythe_great@pm.me>
- Add zarr dependency.
* Sat Dec 19 2020 andy great <andythe_great@pm.me>
- Update to version 2020.12.8.
    Fix corrupted ImageDescription in multi shaped series if buffer too small.
    Fix libtiff warning that ImageDescription contains null byte in value.
    Fix reading invalid files using JPEG compression with palette colorspace.
- Updates for 2020.12.4
    Fix reading some JPEG compressed CFA images.
    Make index of SubIFDs a tuple.
    Pass through FileSequence.imread arguments in imread.
    Do not apply regex flags to FileSequence axes patterns (breaking).
- Updates for 2020.11.26
    Add option to pass axes metadata to ImageJ writer.
    Pad incomplete tiles passed to TiffWriter.write (#38).
    Split TiffTag constructor (breaking).
    Change TiffTag.dtype to TIFF.DATATYPES (breaking).
    Add TiffTag.overwrite method.
    Add script to change ImageDescription in files.
    Add TiffWriter.overwrite_description method (WIP).
- Updates for 2020.11.18
    Support writing SEPARATED color space (#37).
    Use imagecodecs.deflate codec if available.
    Fix SCN and NDPI series with Z dimensions.
    Add TiffReader alias for TiffFile.
    TiffPage.is_volumetric returns True if ImageDepth > 1.
    Zarr store getitem returns numpy arrays instead of bytes.
* Tue Nov 17 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add _constraints file to avoid OOM
* Mon Nov  2 2020 andy great <andythe_great@pm.me>
- Update to version 2020.10.1.
  * Formally deprecate unused TiffFile parameters (scikit-image)
- Disabled test test_write_compression_lerc, python-imagecodecs not
  build with lerc support.
* Fri Sep 18 2020 andy great <andythe_great@pm.me>
- Update to version 2020.9.3.
  * Do not write contiguous series by default (breaking).
  * Allow to write to SubIFDs (WIP).
  * Fix writing F-contiguous numpy arrays.
- Ignore test_write_ome, test_class_omexml_attributes,
  test_class_omexml_multiimage, and test_class_omexml because it
  need network connection.
* Fri Aug 28 2020 Tomáš Chvátal <tchvatal@suse.com>
- Enable testsuite
* Fri Aug 28 2020 Tomáš Chvátal <tchvatal@suse.com>
- Match up versioning to whats in setup.py
* Sat Aug 22 2020 andy great <andythe_great@pm.me>
- Clean up spec file.
* Thu Aug 13 2020 andy great <andythe_great@pm.me>
- Fix ERROR: download_files is configured to fail when the
  upstream file is different than the committed file.
* Sun Aug  9 2020 andy great <andythe_great@pm.me>
- Remove build condition.
- Remove unnecessary dependencies.
* Mon Jul 20 2020 andy great <andythe_great@pm.me>
- Fix spec file build condition.
* Tue Jun  2 2020 andy great <andythe_great@pm.me>
- Update to version 2020.5.30.
  * Re-add pure Python PackBits decoder.
* Mon Mar  4 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2019.2.22
